==> ktp-desktop-applets_0.8.0.orig.tar.bz2: ktp-desktop-applets-0.8.0/contact/plasma-applet-ktp-contact.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Contact
Name[bs]=Kontakt za instant poruke
Name[ca]=Contacte de missatgeria instantània
Name[ca@valencia]=Contacte de missatgeria instantània
Name[cs]=Kontakt komunikátoru
Name[da]=Instant messaging-kontakt
Name[de]=Instant-Messaging-Kontakt 
Name[el]=Επαφή με στιγμιαίο μήνυμα
Name[es]=Contacto de mensajería instantánea
Name[et]=Kiirsuhtluskontakt
Name[fi]=Pikaviestiyhteystiedot
Name[fr]=Contact de messagerie instantanée
Name[ga]=Teagmháil Teachtaireachtaí Meandracha
Name[gl]=Contacto de mensaxería instantánea
Name[hu]=Azonnali üzenetküldési partner
Name[ia]=Contacto de messageria instantanee
Name[it]=Contatto di messaggistica istantanea
Name[kk]=Лезде хабарласу контакты
Name[km]=ទំនាក់ទំនង​ការ​ផ្ញើ​សារ​បន្ទាន់
Name[lt]=Pokalbių kontaktas
Name[mr]=त्वरित संदेश संपर्क
Name[nb]=Lynmeldingskontakt
Name[nl]=Contactpersoon van Instant Messaging
Name[pa]=ਤੁਰੰਤ ਸੁਨੇਹੇ ਸੰਪਰਕ
Name[pl]=Kontakt komunikatora internetowego
Name[pt]=Contacto de Mensagens Instantâneas
Name[pt_BR]=Contato de mensagens instantâneas
Name[ro]=Contact de mesagerie instantanee
Name[ru]=Контакт
Name[sk]=Kontakt instant messagingu
Name[sl]=Stik hipnega sporočanja 
Name[sr]=Брзогласнички контакти
Name[sr@ijekavian]=Брзогласнички контакти
Name[sr@ijekavianlatin]=Brzoglasnički kontakti
Name[sr@latin]=Brzoglasnički kontakti
Name[sv]=Direktmeddelandekontakt
Name[tr]=Anında Mesajlaşma Kişisi
Name[ug]=مۇڭداشقۇ ئالاقەدىشى
Name[uk]=Контакт миттєвого обміну повідомленнями
Name[wa]=Soçon del messaedjreye sol moumint
Name[x-test]=xxInstant Messaging Contactxx
Name[zh_CN]=即时通讯联系
Name[zh_TW]=即時通訊聯絡人
Comment=Applet for one of your instant messaging contacts
Comment[bs]=Programčić za kontakte instant poruka
Comment[ca]=Miniaplicació per un dels contactes de missatgeria instantània
Comment[ca@valencia]=Miniaplicació per un dels contactes de missatgeria instantània
Comment[cs]=Applet pro jeden z vašich kontaktů komunikátoru
Comment[da]=Applet til en af dine instant messaging-kontakter
Comment[de]=Miniprogramm für einen Ihrer Instant-Messaging-Kontakte
Comment[el]=Μικροεφαρμογή για μία από τις επαφές σας με στιγμιαία μηνύματα
Comment[es]=Miniaplicación para uno de sus contactos de mensajería instantánea
Comment[et]=Aplett mõne sinu kiirsuhtluskontakti jaoks
Comment[fi]=Sovelma yhdelle pikaviestiyhteystiedoistasi
Comment[fr]=Composant graphique pour un de vos contacts de messagerie instantanée
Comment[ga]=Feidhmchláirín do dhuine de do chuid teagmhálacha TM
Comment[gl]=Applet para un dos seus contactos de mensaxería instantánea
Comment[hu]=Kisalkalmazás az azonnali üzenetküldési partnerei egyikének kezeléséhez
Comment[ia]=Applet pro un de tu contactos de messageria instantanee
Comment[it]=Applet per uno dei tuoi contatti di messaggistica istantanea
Comment[kk]=Лезде хабарласу бір контакты үшін апплет
Comment[km]=អាប់ភ្លេត​សម្រាប់​ទំនាក់ទំនង​ការ​ផ្ញើ​សារ​បន្ទាន់​របស់​អ្នក​មួយ
Comment[lt]=Programėlė vienam iš jūsų pokalbių kontaktų
Comment[mr]=तुमच्या एका त्वरित संदेश संपर्काकरिता एप्लेट
Comment[nb]=Miniprogram for en av dine lynmeldingskontakter
Comment[nl]=Applet voor één van uw contactpersonen van Instant Messaging
Comment[pa]=ਤੁਹਾਡੇ ਤੁਰੰਤ ਸੁਨੇਹੇ ਸੰਪਰਕਾਂ ਲਈ ਐਪਲਿਟ
Comment[pl]=Aplet dla jednego z kontaktów twojego komunikatora internetowego
Comment[pt]='Applet' para um dos seus contactos das mensagens instantâneas
Comment[pt_BR]=Exibe um dos seus contatos de mensagens instantâneas
Comment[ro]=Miniaplicație pentru unul dintre contactele dumneavoastră de mesagerie instantanee
Comment[ru]=Контакт сети обмена сообщениями
Comment[sk]=Applet pre jeden z vašich kontaktov instant messagingu
Comment[sl]=Aplet za enega izmed vaših stikov hipnega sporočanja
Comment[sr]=Аплет за један од ваших брзогласничких контаката
Comment[sr@ijekavian]=Аплет за један од ваших брзогласничких контаката
Comment[sr@ijekavianlatin]=Aplet za jedan od vaših brzoglasničkih kontakata
Comment[sr@latin]=Aplet za jedan od vaših brzoglasničkih kontakata
Comment[sv]=Miniprogram för en direktmeddelandekontakt
Comment[tr]=Anında mesajlaşma kişilerinizden biri için uygulamacık
Comment[uk]=Аплет одного з ваших записів контактів миттєвого обміну повідомленнями
Comment[wa]=Aplikete po-z onk di vos soçons di messaedjreye sol moumint
Comment[x-test]=xxApplet for one of your instant messaging contactsxx
Comment[zh_CN]=显示某个您的及时通讯联系人的部件
Comment[zh_TW]=您的即時訊息聯絡人
Type=Service
ServiceTypes=Plasma/Applet
Icon=im-user

X-Plasma-DefaultSize=128,128

X-KDE-Library=plasma_applet_ktp_contact
X-KDE-PluginInfo-Name=org.kde.ktp-contact
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=Francesco Nwokeka
X-KDE-PluginInfo-Email=francesco.nwokeka@gmail.com
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DropMimeTypes=application/vnd.telepathy.contact

==> ktp-desktop-applets_0.8.1.orig.tar.bz2: ktp-desktop-applets-0.8.1/contact/plasma-applet-ktp-contact.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Contact
Name[bs]=Kontakt za instant poruke
Name[ca]=Contacte de missatgeria instantània
Name[ca@valencia]=Contacte de missatgeria instantània
Name[cs]=Kontakt komunikátoru
Name[da]=Instant messaging-kontakt
Name[de]=Instant-Messaging-Kontakt 
Name[el]=Επαφή με στιγμιαίο μήνυμα
Name[es]=Contacto de mensajería instantánea
Name[et]=Kiirsuhtluskontakt
Name[fi]=Pikaviestiyhteystiedot
Name[fr]=Contact de messagerie instantanée
Name[ga]=Teagmháil Teachtaireachtaí Meandracha
Name[gl]=Contacto de mensaxería instantánea
Name[hu]=Azonnali üzenetküldési partner
Name[ia]=Contacto de messageria instantanee
Name[it]=Contatto di messaggistica istantanea
Name[kk]=Лезде хабарласу контакты
Name[km]=ទំនាក់ទំនង​ការ​ផ្ញើ​សារ​បន្ទាន់
Name[ko]=인스턴트 메시지 대화 상대
Name[lt]=Pokalbių kontaktas
Name[mr]=त्वरित संदेश संपर्क
Name[nb]=Lynmeldingskontakt
Name[nds]=Kortnarichtenkontakten
Name[nl]=Contactpersoon van Instant Messaging
Name[pl]=Kontakt komunikatora internetowego
Name[pt]=Contacto de Mensagens Instantâneas
Name[pt_BR]=Contato de mensagens instantâneas
Name[ro]=Contact de mesagerie instantanee
Name[ru]=Контакт
Name[sk]=Kontakt instant messagingu
Name[sl]=Stik hipnega sporočanja 
Name[sr]=Брзогласнички контакти
Name[sr@ijekavian]=Брзогласнички контакти
Name[sr@ijekavianlatin]=Brzoglasnički kontakti
Name[sr@latin]=Brzoglasnički kontakti
Name[sv]=Direktmeddelandekontakt
Name[tr]=Anında Mesajlaşma Kişisi
Name[uk]=Контакт миттєвого обміну повідомленнями
Name[wa]=Soçon del messaedjreye sol moumint
Name[x-test]=xxInstant Messaging Contactxx
Name[zh_CN]=即时通讯联系
Name[zh_TW]=即時通訊聯絡人
Comment=Applet for one of your instant messaging contacts
Comment[bs]=Programčić za kontakte instant poruka
Comment[ca]=Miniaplicació per un dels contactes de missatgeria instantània
Comment[ca@valencia]=Miniaplicació per un dels contactes de missatgeria instantània
Comment[cs]=Applet pro jeden z vašich kontaktů komunikátoru
Comment[da]=Applet til en af dine instant messaging-kontakter
Comment[de]=Miniprogramm für einen Ihrer Instant-Messaging-Kontakte
Comment[el]=Μικροεφαρμογή για μία από τις επαφές σας με στιγμιαία μηνύματα
Comment[es]=Miniaplicación para uno de sus contactos de mensajería instantánea
Comment[et]=Aplett mõne sinu kiirsuhtluskontakti jaoks
Comment[fi]=Sovelma yhdelle pikaviestiyhteystiedoistasi
Comment[fr]=Composant graphique pour un de vos contacts de messagerie instantanée
Comment[ga]=Feidhmchláirín do dhuine de do chuid teagmhálacha TM
Comment[gl]=Applet para un dos seus contactos de mensaxería instantánea
Comment[hu]=Kisalkalmazás az azonnali üzenetküldési partnerei egyikének kezeléséhez
Comment[ia]=Applet pro un de tu contactos de messageria instantanee
Comment[it]=Applet per uno dei tuoi contatti di messaggistica istantanea
Comment[kk]=Лезде хабарласу бір контакты үшін апплет
Comment[km]=អាប់ភ្លេត​សម្រាប់​ទំនាក់ទំនង​ការ​ផ្ញើ​សារ​បន្ទាន់​របស់​អ្នក​មួយ
Comment[ko]=특정한 인스턴트 메시지 대화 상대를 위한 애플릿
Comment[lt]=Programėlė vienam iš jūsų pokalbių kontaktų
Comment[mr]=तुमच्या एका त्वरित संदेश संपर्काकरिता एप्लेट
Comment[nb]=Miniprogram for en av dine lynmeldingskontakter
Comment[nl]=Applet voor één van uw contactpersonen van Instant Messaging
Comment[pl]=Aplet dla jednego z kontaktów twojego komunikatora internetowego
Comment[pt]='Applet' para um dos seus contactos das mensagens instantâneas
Comment[pt_BR]=Exibe um dos seus contatos de mensagens instantâneas
Comment[ro]=Miniaplicație pentru unul dintre contactele dumneavoastră de mesagerie instantanee
Comment[ru]=Контакт сети обмена сообщениями
Comment[sk]=Applet pre jeden z vašich kontaktov instant messagingu
Comment[sl]=Aplet za enega izmed vaših stikov hipnega sporočanja
Comment[sr]=Аплет за један од ваших брзогласничких контаката
Comment[sr@ijekavian]=Аплет за један од ваших брзогласничких контаката
Comment[sr@ijekavianlatin]=Aplet za jedan od vaših brzoglasničkih kontakata
Comment[sr@latin]=Aplet za jedan od vaših brzoglasničkih kontakata
Comment[sv]=Miniprogram för en direktmeddelandekontakt
Comment[tr]=Anında mesajlaşma kişilerinizden biri için uygulamacık
Comment[uk]=Аплет одного з ваших записів контактів миттєвого обміну повідомленнями
Comment[wa]=Aplikete po-z onk di vos soçons di messaedjreye sol moumint
Comment[x-test]=xxApplet for one of your instant messaging contactsxx
Comment[zh_CN]=显示某个您的及时通讯联系人的部件
Comment[zh_TW]=您的即時訊息聯絡人
Type=Service
ServiceTypes=Plasma/Applet
Icon=im-user

X-Plasma-DefaultSize=128,128

X-KDE-Library=plasma_applet_ktp_contact
X-KDE-PluginInfo-Name=org.kde.ktp-contact
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=Francesco Nwokeka
X-KDE-PluginInfo-Email=francesco.nwokeka@gmail.com
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-DropMimeTypes=application/vnd.telepathy.contact
